@@ -115,22 +115,24 @@ qx.Class.define("callbackery.ui.form.renderer.NoteForm", {
                 }
                 if ( itemOptions[i].copyOnTap
                         && item.getReadOnly()){
-                    var copyFailMsg = itemOptions[i].copyFailMsg || 
-                        that.tr("Select %1 and press [ctrl]+[c]",labelName);
-                    var copySuccessMsg = itemOptions[i].copySuccessMsg || 
-                        that.tr("%1 copied",labelName);
+                    var copyFailMsg = itemOptions[i].copyFailMsg
+                        ? that.xtr(itemOptions[i].copyFailMsg)
+                        : that.tr("Select %1 and press [ctrl]+[c]",labelName);
+                    var copySuccessMsg = itemOptions[i].copySuccessMsg ?
+                        ? that.xtr(itemOptions[i].copySuccessMsg)
+                        : that.tr("%1 copied",labelName);
 
                     item.addListener('tap',function(e){
                         try {
                             navigator.clipboard.writeText(item.getValue())
                             .then(function(ret){ 
-                                msg.info(that.tr("Success"),that.xtr(copySuccessMsg));
+                                msg.info(that.tr("Success"),copySuccessMsg);
                             })
                             .catch(function(err){ 
-                                msg.info(that.tr("Copy failed"),that.xtr(copyFailMsg));
+                                msg.info(that.tr("Copy failed"),copyFailMsg);
                             })
                         } catch (err) {
-                            msg.info(that.tr("Copy failed"),that.xtr(copyFailMsg));
+                            msg.info(that.tr("Copy failed"),copyFailMsg);
                         }
                     });
                 }
